Learn R Programming

faraway (version 1.0.6)

snail: Snail production

Description

A study was conducted to optimize snail production for consumption. The percentage water content of the tissues of snails grown under three different levels of relative humidity and two different temperatures was recorded. For each combination, 4 snails were observed.

Usage

data(snail)

Arguments

source

Unknown

Examples

Run this code
data(snail)
## maybe str(snail) ; plot(snail) ...

Run the code above in your browser using DataLab